import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

const originalPush = Router.prototype.push
Router.prototype.push = function (location) {
  originalPush.call(this, location).catch((err) => err)
}

/* AppLayout */
import AppLayout from '@/layout/app/index.vue'

/* MainDefaultLayout */
import MainDefaultLayout from '@/layout/main/default/index.vue'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: '/404',
    component: () => import('@/views/404.vue'),
    hidden: true,
  },

  {
    path: '/',
    redirect: '/hdlb',
  },

  {
    path: '/hdlb',
    // name: 'hdlb',
    component: AppLayout,
    meta: { title: '活动列表' },
    // redirect: '/hdlb',

    children: [
      {
        path: '',
        name: 'hdlb',
        component: () => import('@/views/hdlb/index.vue'),
        meta: { title: '活动列表', icon: 'el-icon-document' },
      },
      {
        path: 'hdfq',
        name: 'hdfq',
        hidden: true,
        component: () => import('@/views/hdlb/hdfq/index.vue'),
        meta: { title: '活动发起' },
      },
      {
        path: 'hdjg/:id',
        name: 'hdjg',
        hidden: true,
        component: () => import('@/views/hdlb/hdjg/index.vue'),
        meta: { title: '活动结果' },
        props: true,
      },
    ],
  },

  {
    path: '/xtgl',
    component: AppLayout,
    redirect: '/xtgl/zzjg',
    name: 'xtgl',
    meta: { title: '系统管理', icon: 'el-icon-setting' },
    children: [
      {
        path: 'zzjg',
        // name: 'zzjg',
        component: MainDefaultLayout,
        meta: { title: '组织架构' },
        children: [
          {
            path: '',
            name: 'zzjg',
            component: () => import('@/views/xtgl/zzjg/index.vue'),
            meta: { title: '组织架构' },
          },
        ],
      },
      {
        path: 'rzgl',
        // name: 'rzgl',
        component: MainDefaultLayout,
        meta: { title: '日志管理' },
        children: [
          {
            path: '',
            name: 'rzgl',
            component: () => import('@/views/xtgl/rzgl/index.vue'),
            meta: { title: '日志管理' },
          },
        ],
      },
      {
        path: 'zdb',
        // name: 'zdb',
        component: MainDefaultLayout,
        meta: { title: '字典表' },
        children: [
          {
            path: '',
            name: 'zdb',
            component: () => import('@/views/xtgl/zdb/index.vue'),
            meta: { title: '字典表' },
          },
        ],
      },
      {
        path: 'pfmb',
        // name: 'pfmb',
        component: MainDefaultLayout,
        meta: { title: '评分模板' },
        children: [
          {
            path: '',
            name: 'pfmb',
            component: () => import('@/views/xtgl/pfmb/index.vue'),
            meta: { title: '评分模板' },
          },
        ],
      },
      {
        path: 'hdlxgl',
        // name: 'hdlxgl',
        component: MainDefaultLayout,
        meta: { title: '活动类型管理' },
        children: [
          {
            path: '',
            name: 'hdlxgl',
            component: () => import('@/views/xtgl/hdlxgl/index.vue'),
            meta: { title: '活动类型管理' },
          },
        ],
      },
    ],
  },

  {
    path: '/mhgl',
    component: AppLayout,
    redirect: '/mhgl/tzgg',
    name: 'mhgl',
    meta: {
      title: '门户管理',
      icon: 'el-icon-document-copy',
    },
    children: [
      {
        path: 'tzgg',
        // name: 'tzgg',
        component: MainDefaultLayout,
        meta: { title: '通知公告' },
        children: [
          {
            path: '',
            name: 'tzgg',
            component: () => import('@/views/mhgl/tzgg/index.vue'),
            meta: { title: '通知公告' },
          },
        ],
      },
      {
        path: 'hdgg',
        // name: 'hdgg',
        component: MainDefaultLayout,
        meta: { title: '活动公告' },
        children: [
          {
            path: '',
            name: 'hdgg',
            component: () => import('@/views/mhgl/hdgg/index.vue'),
            meta: { title: '活动公告' },
          },
        ],
      },
      {
        path: 'yxzp',
        // name: 'yxzp',
        component: MainDefaultLayout,
        meta: { title: '优秀作品' },
        children: [
          {
            path: '',
            name: 'yxzp',
            component: () => import('@/views/mhgl/yxzp/index.vue'),
            meta: { title: '优秀作品' },
          },
        ],
      },
      {
        path: 'wjdc',
        // name: 'wjdc',
        component: MainDefaultLayout,
        meta: { title: '问卷调查' },
        children: [
          {
            path: '',
            name: 'wjdc',
            component: () => import('@/views/mhgl/wjdc/index.vue'),
            meta: { title: '问卷调查' },
          },
        ],
      },
      {
        path: 'tplb',
        // name: 'tplb',
        component: MainDefaultLayout,
        meta: { title: '投票列表' },
        children: [
          {
            path: '',
            name: 'tplb',
            component: () => import('@/views/mhgl/tplb/index.vue'),
            meta: { title: '投票列表' },
          },
        ],
      },
    ],
  },

  // 404 page must be placed at the end !!!
  { path: '*', redirect: '/404', hidden: true },
]

const createRouter = () =>
  new Router({
    // mode: 'history', // require service support
    scrollBehavior: () => ({ y: 0 }),
    routes: constantRoutes,
  })

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router

/* 
=====================================================================================
=====================================================================================
*/
import getPageTitle from '@/utils/get-page-title'
router.beforeEach(async (to, from, next) => {
  document.title = getPageTitle(to.meta.title)
  next()
})
